# MeEP

MeEP stands for **Me**thane **E**missions from **P**onds and is a model for exactly that. MeEP was developed for small waterbodies in permafrost regions and accounts for freezing and thawing of both the water column and the sourrounding soil. MeEP includes the three main pathways of methane emission: diffusion, ebullition and plant-mediated transport. This version was tuned and set up to represent the polygonal tundra in the Lena River Delta, RU. 

## Structure

MeEP consists of four modules:
* Pond physics module
    * The pond physics module is an adapted version of FLake, an open-source lake model (http://www.flake.igb-berlin.de/)
* Hydrology module
    * The hydrology module estimates first-order estimates of water-level change.
* Soil-heat module
    * The soil-heat module is an adapted version of CryoGRID Lite (Langer et al., 2022)
* Methane module    
    * The methane module contains all both the winter and summer dynamics of MeEP


## Running MeEP

### Requirements

* ksh shell with python installation 

* Python packages:
   * cython
   * datetime
   * f90wrap
   * libcpp
   * matplotlib
   * numpy
   * pandas
   * pickle
   * sys
   * warnings
   * xarray

### Compiling    
* FLake
        run `sh compile_FLake.sh` in shell in ./FLake to compile 
    
* Hydrology, Soil Heat and Methane modules
        run `python setup.py build_ext --inplace` in shell ./\<module> to compile
        

### Running

* In run_MeEP set all the paths correctly. Especially, set the absolute path the FLake module.
* MeEP needs the following variables as input. An example run script is provided 
(run_MeEP.py)

|MeEP Name  | Unit      |  Long name|
|--- | --- | ---|
|I_atm    |   J m-2 s-1  | Incoming shortwave radiation at the surface|
|Q_atm_lw |   J m-2 s-1  | Incoming longwave radiation at the surface|
|U_a      |   m s−1      | Wind speed|
|T_a      |   K          | Air temperature close to the surface|
|q_a      |   kg kg-1    | Specific humidity close to the surface|
|P_a      |   Pa         | Air pressure at the surface|
|tp       |   m          | Total precipitation|
|npp      |   mol m-2    | Net-primary productivity|
|LAI      |   m2 m-2      |leaf-area index|

## Acknowledgment
The methane module builds on ideas by Victor Stepanenko. MeEP includes the lake model FLake (http://www.flake.igb-berlin.de) and the soil-heat model CRYOGRIDLite (https://zenodo.org/record/6619537).

Langer, Moritz, Nitzbon, Jan, & Oehme, Alexander. (2022). CryoGridLite: Model code for pan-Arctic 
simulations at 1° resolution from 1700 to 2020. Zenodo. https://doi.org/10.5281/zenodo.6619537

## License
This project is licensed under the BSD 3-Clause
